@@ -1,8 +1,10 @@
+# frozen_string_literal: true
+
 # = Public Suffix
 #
 # Domain name parser based on the Public Suffix List.
 #
-# Copyright (c) 2009-2018 Simone Carletti <weppos@weppos.net>
+# Copyright (c) 2009-2022 Simone Carletti <weppos@weppos.net>
 
 module PublicSuffix
 
@@ -46,7 +48,7 @@ module PublicSuffix
     #
     # @return [PublicSuffix::List]
     def self.default(**options)
-      @default ||= parse(File.read(DEFAULT_LIST_PATH), options)
+      @default ||= parse(File.read(DEFAULT_LIST_PATH), **options)
     end
 
     # Sets the default rule list to +value+.
@@ -61,12 +63,12 @@ module PublicSuffix
     #
     # See http://publicsuffix.org/format/ for more details about input format.
     #
-    # @param  string [#each_line] the list to parse
+    # @param  input [#each_line] the list to parse
     # @param  private_domains [Boolean] whether to ignore the private domains section
     # @return [PublicSuffix::List]
     def self.parse(input, private_domains: true)
-      comment_token = "//".freeze
-      private_token = "===BEGIN PRIVATE DOMAINS===".freeze
+      comment_token = "//"
+      private_token = "===BEGIN PRIVATE DOMAINS==="
       section = nil # 1 == ICANN, 2 == PRIVATE
 
       new do |list|
@@ -81,10 +83,11 @@ module PublicSuffix
           # include private domains or stop scanner
           when line.include?(private_token)
             break if !private_domains
+
             section = 2
 
           # skip comments
-          when line.start_with?(comment_token)
+          when line.start_with?(comment_token) # rubocop:disable Lint/DuplicateBranch
             next
 
           else
@@ -116,6 +119,7 @@ module PublicSuffix
     # @return [Boolean]
     def ==(other)
       return false unless other.is_a?(List)
+
       equal?(other) || @rules == other.rules
     end
     alias eql? ==
@@ -169,7 +173,8 @@ module PublicSuffix
     # @return [PublicSuffix::Rule::*]
     def find(name, default: default_rule, **options)
       rule = select(name, **options).inject do |l, r|
-        return r if r.class == Rule::Exception
+        return r if r.instance_of?(Rule::Exception)
+
         l.length > r.length ? l : r
       end
       rule || default
@@ -201,12 +206,11 @@ module PublicSuffix
 
       loop do
         match = @rules[query]
-        if !match.nil? && (ignore_private == false || match.private == false)
-          rules << entry_to_rule(match, query)
-        end
+        rules << entry_to_rule(match, query) if !match.nil? && (ignore_private == false || match.private == false)
 
         index += 1
         break if index >= parts.size
+
         query = parts[index] + DOT + query
       end
 
